==> AGXUnreal-1.17.0_UE-5.4_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics3D/Signals/RPYOutput.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics/Signals/Output.h>
#include <openplx/Physics3D/Signals/RPYOutputTrait.h>
/* Generated code for model RPYOutput */
namespace openplx::Physics3D::Signals {
    /**
     * A Roll Pitch Yaw output given an interaction.
     * For interactions where it is unambiguous which position is requested,
     * the output will give the current value.
     **/
    class RPYOutput : public openplx::Physics::Signals::Output {
        protected:
            std::weak_ptr<openplx::Physics3D::Signals::RPYOutputTrait> m_source;

        public:
            RPYOutput();
            std::shared_ptr<openplx::Physics3D::Signals::RPYOutputTrait> source() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

==> AGXUnreal-2.0.0_UE-5.6_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics3D/Signals/RPYOutput.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics3D/Physics3DBundleExport.h>
#include <openplx/Physics3D/Physics3DForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Physics/Signals/Output.h>
#include <openplx/Physics3D/Signals/RPYOutputTrait.h>

#ifdef _MSC_VER
#  pragma warning(push)
#  pragma warning(disable: 4251)
#endif

/* Generated code for model RPYOutput */
namespace openplx::Physics3D::Signals {
    /**
     * A Roll Pitch Yaw output given an interaction.
     * For interactions where it is unambiguous which position is requested,
     * the output will give the current value.
     **/
    class OPENPLX_Physics3D_BUNDLE_EXPORT RPYOutput : public openplx::Physics::Signals::Output {
        protected:
            std::weak_ptr<openplx::Physics3D::Signals::RPYOutputTrait> m_source;

        public:
            RPYOutput();
            virtual ~RPYOutput();
            std::shared_ptr<openplx::Physics3D::Signals::RPYOutputTrait> source() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

#ifdef _MSC_VER
#  pragma warning(pop)
#endif
